@@ -1,6 +1,6 @@
 ;;; geiser-repl.el --- Geiser's REPL
 
-;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009, 2010, 2011 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -399,7 +399,6 @@ module command as a string")
       (buffer-substring (point) end))))
 
 (defun geiser-repl--quit-setup ()
-  (set (make-local-variable 'comint-get-old-input) 'geiser-repl--old-input)
   (add-hook 'kill-buffer-hook 'geiser-repl--on-kill nil t)
   (set-process-sentinel (get-buffer-process (current-buffer))
                         'geiser-repl--sentinel))
@@ -474,7 +473,7 @@ module command as a string")
                  (geiser-repl--newline-and-indent)
                (insert "\n"))))))
 
-(defun geiser-repl--tab (n)
+(defun geiser-repl-tab-dwim (n)
   "If we're after the last prompt, complete symbol or indent (if
 there's no symbol at point). Otherwise, go to next error in the REPL
 buffer."
@@ -493,7 +492,7 @@ buffer."
 \\{geiser-repl-mode-map}"
   (scheme-mode-variables)
   (set (make-local-variable 'mode-line-process) nil)
-  (set (make-local-variable 'comint-use-prompt-regexp) nil)
+  (set (make-local-variable 'comint-use-prompt-regexp) t)
   (set (make-local-variable 'comint-prompt-read-only)
        geiser-repl-read-only-prompt-p)
   (set (make-local-variable 'beginning-of-defun-function)
@@ -512,7 +511,7 @@ buffer."
 (define-key geiser-repl-mode-map "\C-m" 'geiser-repl--maybe-send)
 (define-key geiser-repl-mode-map [return] 'geiser-repl--maybe-send)
 (define-key geiser-repl-mode-map "\C-j" 'geiser-repl--newline-and-indent)
-(define-key geiser-repl-mode-map (kbd "TAB") 'geiser-repl--tab)
+(define-key geiser-repl-mode-map (kbd "TAB") 'geiser-repl-tab-dwim)
 (define-key geiser-repl-mode-map [backtab] 'geiser-repl--previous-error)
 
 (define-key geiser-repl-mode-map "\C-a" 'geiser-repl--bol)
@@ -520,7 +519,7 @@ buffer."
 
 (geiser-menu--defmenu repl geiser-repl-mode-map
   ("Complete symbol" ((kbd "M-TAB"))
-   geiser-repl--tab :enable (geiser--symbol-at-point))
+   completion-at-point :enable (geiser--symbol-at-point))
   ("Complete module name" ((kbd "C-.") (kbd "M-`"))
    geiser-completion--complete-module :enable (geiser--symbol-at-point))
   ("Edit symbol" "\M-." geiser-edit-symbol-at-point
